@@ -224,7 +224,7 @@ lrEM <- function(X,label=NULL,dl=NULL,rob=FALSE,ini.cov=c("complete.obs","multRe
       M <- matrix(colMeans(X_alr,na.rm=T),ncol=1)
       C <- cov(X_alr,use=ini.cov)}
     else {
-        X.mr <- multRepl(X,label=NA,dl=dl,frac=frac,imp.missing=imp.missing,closure=closure)
+        X.mr <- multRepl(X,label=NA,dl=dl,frac=frac,imp.missing=imp.missing,closure=closure,z.warning=z.warning,z.delete=z.delete)
         if (any(X.mr < 0)) {stop("ini.cov: negative values produced using multRepl (please check out closure argument and multRepl help for advice)")}
         X.mr_alr <- t(apply(X.mr,1,function(x) log(x)-log(x[pos])))[,-pos]
         M <- matrix(colMeans(X.mr_alr,na.rm=T),ncol=1)
@@ -252,7 +252,7 @@ lrEM <- function(X,label=NULL,dl=NULL,rob=FALSE,ini.cov=c("complete.obs","multRe
         varobs <- which(!is.na(X_alr[i[1],]))
         if (length(varobs) == 0){
           alt.in <- TRUE
-          temp <- multRepl(X[i,,drop=FALSE],label=NA,dl=dl[i,,drop=FALSE],frac=frac,imp.missing=imp.missing,closure=closure)
+          temp <- multRepl(X[i,,drop=FALSE],label=NA,dl=dl[i,,drop=FALSE],frac=frac,imp.missing=imp.missing,closure=closure,z.warning=z.warning,z.delete=z.delete)
           Y[i,] <- t(apply(temp,1,function(x) log(x)-log(x[pos])))[,-pos]
           if (niters == 1){
             alt.pat <- c(alt.pat,npat)
@@ -303,10 +303,10 @@ lrEM <- function(X,label=NULL,dl=NULL,rob=FALSE,ini.cov=c("complete.obs","multRe
     
     if (ini.cov == "multRepl"){
      if (imp.missing == TRUE){
-          X.mr <- multRepl(X,label=NA,imp.missing=T,closure=closure)
+          X.mr <- multRepl(X,label=NA,imp.missing=T,closure=closure,z.warning=z.warning,z.delete=z.delete)
           if (any(X.mr < 0)) {stop("ini.cov: negative values produced using multRepl (please check out closure argument and multRepl help for advice)")}
           }
-     else {X.mr <- multRepl(X,label=NA,dl=dl,frac=frac,closure=closure)
+     else {X.mr <- multRepl(X,label=NA,dl=dl,frac=frac,closure=closure,z.warning=z.warning,z.delete=z.delete)
            if (any(X.mr < 0)) {stop("ini.cov: negative values produced using multRepl (please check out closure argument and multRepl help for advice)")}
           }
     }
@@ -335,7 +335,7 @@ lrEM <- function(X,label=NULL,dl=NULL,rob=FALSE,ini.cov=c("complete.obs","multRe
           if (imp.missing==FALSE){
             X[misspat==npat,] <- multRepl(X.old[misspat==npat,,drop=FALSE],
                                           label=NA,dl=dl[misspat==npat,,drop=FALSE],
-                                          frac=frac,closure=closure)    
+                                          frac=frac,closure=closure,z.warning=z.warning,z.delete=z.delete)    
           }
           if (imp.missing==TRUE){
             stop("Please remove samples with only one observed component (check it out using zPatterns).")
